@@ -1,10 +1,9 @@
 import win32con
-import threading
 import time
-from PyQt5.QtCore import QCoreApplication
 from xyw_macro.notify import Notification
 from xyw_macro.utils import SingletonType
 from xyw_macro.win32 import *
+from xyw_macro.contants import SLEEP_TIME
 
 
 class HookConstants:
@@ -296,13 +295,14 @@ class Condition:
     """
     条件类，用来判断键盘事件是否符合命令触发条件
     """
-    def __init__(self, vk=None, alias=None, repeat=False):
+    def __init__(self, vk=None, alias=None, repeat=False, show=True):
         # 虚拟键号
         self.vk = vk
         # 命令别名
         self.alias = alias
         # 是否支持按住连续触发（默认根据松开按键触发命令）
         self.repeat = repeat
+        self.show = show
 
     def inspect(self, event):
         """
@@ -341,7 +341,7 @@ class Configuration:
     # 模式
     _MODE = ('part', 'all')
 
-    def __init__(self, name, mode='part', parts=None):
+    def __init__(self, name, mode='part', parts=None, excepts=None):
         """
         初始化实例
         :param name: 配置名称
@@ -354,6 +354,7 @@ class Configuration:
             self.__parts = self.FUNCTION
         else:
             self.__parts = parts
+        self.__excepts = excepts
 
         self.__commands = {}
 
@@ -370,7 +371,12 @@ class Configuration:
             raise TypeError('the second param must be callable')
         if not HookConstants.is_vk(condition.vk):
             raise ValueError('condition\'s attr vk is not a vkey code')
-        self.__commands[condition.vk] = Command(condition, func)
+        key = str(condition.vk)
+        if condition.repeat:
+            key = key + '_p'
+        else:
+            key = key + '_r'
+        self.__commands[key] = Command(condition, func)
 
     def get_commands(self):
         """
@@ -417,8 +423,29 @@ class Configuration:
                 raise ValueError('invalid key code {}'.format(key))
         self.__parts = tuple(parts)
 
+    def get_excepts(self):
+        """
+        获取快捷键区列表
+        :return:
+        """
+        return self.__excepts
+
+    def set_excepts(self, excepts):
+        """
+        设置快捷键区列表
+        :param excepts:
+        :return:
+        """
+        if not isinstance(excepts, (list, tuple)):
+            raise TypeError('must be list or tuple')
+        for key in excepts:
+            if not HookConstants.is_vk(key):
+                raise ValueError('invalid key code {}'.format(key))
+        self.__excepts = tuple(excepts)
+
     mode = property(get_mode, set_mode)
     parts = property(get_parts, set_parts)
+    excepts = property(get_excepts, set_excepts)
     commands = property(get_commands)
 
 
@@ -499,6 +526,7 @@ class Core(metaclass=SingletonType):
 
         # 切换按键相关逻辑
         if event.vk_code == self.__switch_key:
+            # print('x')
             if HookConstants.is_keyup(event.w_param):
                 if self.__last_key.vk_code == self.__switch_key \
                         and (event.time - self.__last_key.time) >= self.__active_time:
@@ -521,38 +549,47 @@ class Core(metaclass=SingletonType):
         # 判断是否已进入宏模式
         if not self.__flag_start:
             if event.vk_code == self.__switch_key:
+                # print('pass')
                 return 1
             return 0
 
+        config = self.__configs[self.__current_config]
+
+        # 部分模式下放行所有非快捷区域键盘输入
+        if config.mode == 'part' and (event.vk_code not in config.parts) and event.vk_code != self.__switch_key:
+            # print('no')
+            return 0
+
+        # 全部模式下放行所有非快捷区域键盘输入
+        if config.mode == 'all' and (event.vk_code in config.excepts) and event.vk_code != self.__switch_key:
+            return 0
+
         # 判断是否有命令正在执行中
         if self.__flag_run:
             if event.vk_code == self.__repeat_key and HookConstants.is_keyup(event.w_param):
                 self.__repeat_key = None
-                return 1
+                if (str(event.vk_code) + '_r') not in config.commands.keys():
+                    return 1
             self.__show_message('执行中,\n请等待!')
             return 1
 
         # 切换配置相关逻辑
         if event.vk_code == self.__switch_key and HookConstants.is_keyup(event.w_param):
+            # print('change')
             self.__next_config()
             self.__show_message('配置\n{}'.format(self.__configs[self.__current_config].name))
             return 1
         elif event.vk_code == self.__switch_key and HookConstants.is_keydown(event.w_param):
             return 1
 
-        # 部分模式下放行所有非快捷区域键盘输入
-        config = self.__configs[self.__current_config]
-        if config.mode == 'part' and event.vk_code not in config.parts:
-            return 0
-
         # 判断按键是否触发相关命令函数
-        # inspect_flag = False
         for command in config.commands.values():
             if command.condition.inspect(event):
-                if command.condition.alias is None:
-                    self.__show_message('命令\n{}'.format(ID(command.condition.vk)))
-                else:
-                    self.__show_message('命令\n{}'.format(command.condition.alias))
+                if command.condition.show:
+                    if command.condition.alias is None:
+                        self.__show_message('命令\n{}'.format(ID(command.condition.vk)))
+                    else:
+                        self.__show_message('命令\n{}'.format(command.condition.alias))
                 if command.condition.repeat:
                     self.__repeat_key = event.vk_code
 
@@ -566,9 +603,9 @@ class Core(metaclass=SingletonType):
                     self.__flag_run = False
 
                 self.__pool.submit(callback)
-                # inspect_flag = True
                 return 1
-            elif command.condition.vk == event.vk_code and HookConstants.is_keyup(event.w_param):
+            elif command.condition.vk == event.vk_code and HookConstants.is_keyup(event.w_param) \
+                    and ((str(event.vk_code) + '_r') not in config.commands.keys()):
                 return 1
         if HookConstants.is_keyup(event.w_param):
             self.__show_message('命令\n空')
@@ -586,7 +623,7 @@ class Core(metaclass=SingletonType):
         time.sleep(duration)
         self.__window.hide()
 
-    def __show_message(self, text, duration=0.5):
+    def __show_message(self, text, duration=SLEEP_TIME):
         """
         后台线程运行窗体显示函数
         :param text:
