@@ -3,9 +3,10 @@ import time
 
 from xyw_macro.hook import KbHook, Core
 from xyw_macro.notify import Notification
+from xyw_macro.utils import SingletonType
 
 
-class Macro:
+class Macro(metaclass=SingletonType):
     """
     最终封装好的宏命令类，只能在主线程中定义使用
     """
